@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package App::pherkin 0.85;
+package App::pherkin 0.86;
 
 
 use lib;
@@ -25,7 +25,7 @@ use Moo;
 use Types::Standard qw( ArrayRef Bool Str );
 has 'step_paths' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
 has 'extensions' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
-has 'tags'       => ( is => 'rw', isa => Str,      required => 0 );
+has 'tags'       => ( is => 'rw', isa => Str,      default => '' );
 has 'match_only' => ( is => 'rw', isa => Bool,     default => 0 );
 has 'matching'   => ( is => 'rw', isa => Str,      default => 'first');
 has 'strict'     => ( is => 'rw', isa => Bool,     default => 0 );
@@ -38,7 +38,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 SYNOPSIS
 
@@ -482,6 +482,8 @@ sub _process_arguments {
     # Store any extra step paths
     $self->step_paths( $deref->('steps') );
 
+    $self->tags( $deref->('tags') // '' );
+
     $self->matching( $deref->('matching') )
         if $deref->('matching');
 
